@@ -33,7 +33,7 @@ class ColumnPlugin(CMSPluginBase):
     module = _("Multi Columns")
     name = _("Column")
     render_template = "cms/plugins/column.html"
-    #frontend_edit_template = 'cms/plugins/column_edit.html'
+    parent_classes = ["MultiColumnPlugin"]
     allow_children = True
 
     def render(self, context, instance, placeholder):
